Membrane.H26x.AccessUnit (Membrane H.264 and H.265 plugin v0.11.2)

Copy Markdown View Source

A module defining a struct representing a single access unit.

Summary

Types

t()

A type defining the structure of a single access unit produced by the parsing engine.

Types

t()

@type t() :: %Membrane.H26x.AccessUnit{
  keyframe?: boolean(),
  nalus: [Membrane.H26x.NALu.t()],
  nalus_payloads: [binary()],
  timestamps: Membrane.H26x.NALu.timestamps()
}

A type defining the structure of a single access unit produced by the parsing engine.

In the structure there are following fields:

  • nalus - the list of logically associated NAL units making up the access unit.
  • nalus_payloads - the payloads of the NALus (in the same order), prefixed for the output stream structure and ready to be output.
  • timestamps - the {pts, dts} of the access unit - taken from its first VCL NALu or generated by the parsing engine ({nil, nil} if neither is available).
  • keyframe? - whether the access unit contains a keyframe.